@@ -4,17 +4,31 @@ Asynchronous admin API requests.
 from typing import List, Dict, Optional
 
 from algora.api.service.admin.__util import (
-    _get_client_id_request_info, _get_users_request_info, _get_user_request_info, _update_user_request_info,
-    _get_groups_request_info, _get_group_members_request_info, _add_group_to_user_request_info,
-    _delete_group_from_user_request_info, _get_roles_request_info, _get_roles_for_user_request_info,
-    _add_role_mapping_to_user_request_info, _execute_actions_email_request_info, _delete_offline_token_request_info,
-    _update_offline_token_request_info, _create_offline_token_request_info, _get_offline_token_request_info,
-    _get_user_count_request_info
+    _get_client_id_request_info,
+    _get_users_request_info,
+    _get_user_request_info,
+    _update_user_request_info,
+    _get_groups_request_info,
+    _get_group_members_request_info,
+    _add_group_to_user_request_info,
+    _delete_group_from_user_request_info,
+    _get_roles_request_info,
+    _get_roles_for_user_request_info,
+    _add_role_mapping_to_user_request_info,
+    _execute_actions_email_request_info,
+    _delete_offline_token_request_info,
+    _update_offline_token_request_info,
+    _create_offline_token_request_info,
+    _get_offline_token_request_info,
+    _get_user_count_request_info,
 )
 from algora.common.decorators import async_data_request
 from algora.common.function import no_transform
 from algora.common.requests import (
-    __async_get_request, __async_put_request, __async_post_request, __async_delete_request
+    __async_get_request,
+    __async_put_request,
+    __async_post_request,
+    __async_delete_request,
 )
 
 
@@ -70,7 +84,9 @@ async def async_get_user(user_id: str):
 
 
 @async_data_request(transformers=[no_transform], processor=lambda r: r)
-def async_execute_actions_email(user_id: str, actions: List[str], client_id: str, redirect_uri: str):
+def async_execute_actions_email(
+    user_id: str, actions: List[str], client_id: str, redirect_uri: str
+):
     """
     Asynchronously update user.
 
@@ -83,7 +99,9 @@ def async_execute_actions_email(user_id: str, actions: List[str], client_id: str
     Returns:
         User response
     """
-    request_info = _execute_actions_email_request_info(user_id, actions, client_id, redirect_uri)
+    request_info = _execute_actions_email_request_info(
+        user_id, actions, client_id, redirect_uri
+    )
     return __async_put_request(**request_info)
 
 
@@ -221,7 +239,9 @@ async def async_get_offline_token(user_id: str) -> dict:
 
 
 @async_data_request(transformers=[no_transform])
-async def async_create_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
+async def async_create_offline_token(
+    user_id: str, refresh_token: str, exp: Optional[int] = None
+) -> dict:
     """
     Asynchronously create offline token for user.
 
@@ -238,7 +258,9 @@ async def async_create_offline_token(user_id: str, refresh_token: str, exp: Opti
 
 
 @async_data_request(transformers=[no_transform])
-async def async_update_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
+async def async_update_offline_token(
+    user_id: str, refresh_token: str, exp: Optional[int] = None
+) -> dict:
     """
     Asynchronously update offline token for user.
 
