@@ -4,17 +4,31 @@ Admin API requests.
 from typing import List, Dict, Optional
 
 from algora.api.service.admin.__util import (
-    _get_client_id_request_info, _get_users_request_info, _get_user_request_info, _update_user_request_info,
-    _get_groups_request_info, _get_group_members_request_info, _add_group_to_user_request_info,
-    _delete_group_from_user_request_info, _get_roles_request_info, _get_roles_for_user_request_info,
-    _add_role_mapping_to_user_request_info, _execute_actions_email_request_info, _create_offline_token_request_info,
-    _update_offline_token_request_info, _get_offline_token_request_info, _delete_offline_token_request_info,
-    _get_user_count_request_info
+    _get_client_id_request_info,
+    _get_users_request_info,
+    _get_user_request_info,
+    _update_user_request_info,
+    _get_groups_request_info,
+    _get_group_members_request_info,
+    _add_group_to_user_request_info,
+    _delete_group_from_user_request_info,
+    _get_roles_request_info,
+    _get_roles_for_user_request_info,
+    _add_role_mapping_to_user_request_info,
+    _execute_actions_email_request_info,
+    _create_offline_token_request_info,
+    _update_offline_token_request_info,
+    _get_offline_token_request_info,
+    _delete_offline_token_request_info,
+    _get_user_count_request_info,
 )
 from algora.common.decorators import data_request
 from algora.common.function import no_transform
 from algora.common.requests import (
-    __get_request, __put_request, __post_request, __delete_request
+    __get_request,
+    __put_request,
+    __post_request,
+    __delete_request,
 )
 
 
@@ -70,7 +84,9 @@ def get_user(user_id: str):
 
 
 @data_request(transformers=[no_transform], processor=lambda r: r)
-def execute_actions_email(user_id: str, actions: List[str], client_id: str, redirect_uri: str):
+def execute_actions_email(
+    user_id: str, actions: List[str], client_id: str, redirect_uri: str
+):
     """
     Update user.
 
@@ -83,7 +99,9 @@ def execute_actions_email(user_id: str, actions: List[str], client_id: str, redi
     Returns:
         User response
     """
-    request_info = _execute_actions_email_request_info(user_id, actions, client_id, redirect_uri)
+    request_info = _execute_actions_email_request_info(
+        user_id, actions, client_id, redirect_uri
+    )
     return __put_request(**request_info)
 
 
@@ -221,7 +239,9 @@ def get_offline_token(user_id: str) -> dict:
 
 
 @data_request(transformers=[no_transform])
-def create_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
+def create_offline_token(
+    user_id: str, refresh_token: str, exp: Optional[int] = None
+) -> dict:
     """
     Create offline token for user.
 
@@ -238,7 +258,9 @@ def create_offline_token(user_id: str, refresh_token: str, exp: Optional[int] =
 
 
 @data_request(transformers=[no_transform])
-def update_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
+def update_offline_token(
+    user_id: str, refresh_token: str, exp: Optional[int] = None
+) -> dict:
     """
     Update offline token for user.
 
