@@ -4,7 +4,10 @@ from typing import Dict, Any, Optional
 import pandas as pd
 from pandas import DataFrame
 
-from algora.api.service.data_engine.__util import _analyze_data_request_info, _transform_data_request_info
+from algora.api.service.data_engine.__util import (
+    _analyze_data_request_info,
+    _transform_data_request_info,
+)
 from algora.api.service.data_engine.model import TransformOverride
 from algora.common.decorators import data_request
 from algora.common.function import no_transform
@@ -17,7 +20,12 @@ def analyze_data(data: pd.DataFrame) -> Dict[str, Any]:
     return __post_request(**request_info)
 
 
-@data_request(processor=lambda r: r.content, transformers=[lambda r: pd.read_parquet(io.BytesIO(r))])
-def transform_data(data: pd.DataFrame, transform_override: Optional[TransformOverride] = None) -> DataFrame:
+@data_request(
+    processor=lambda r: r.content,
+    transformers=[lambda r: pd.read_parquet(io.BytesIO(r))],
+)
+def transform_data(
+    data: pd.DataFrame, transform_override: Optional[TransformOverride] = None
+) -> DataFrame:
     request_info = _transform_data_request_info(data, transform_override)
     return __post_request(**request_info)
