@@ -2,4 +2,4 @@ from algora.common.base_enum import BaseEnum
 
 
 class DatasetDataType(BaseEnum):
-    STOCK = 'STOCK'
+    STOCK = "STOCK"
