@@ -1,14 +1,20 @@
 from typing import Dict, Any, List
 
 from algora.api.service.documents.__util import (
-    _get_document_request_info, _search_documents_request_info, _create_document_request_info,
-    _update_document_request_info, _delete_document_request_info
+    _get_document_request_info,
+    _search_documents_request_info,
+    _create_document_request_info,
+    _update_document_request_info,
+    _delete_document_request_info,
 )
 from algora.api.service.documents.model import SearchDocumentRequest, DocumentRequest
 from algora.common.decorators import data_request
 from algora.common.function import no_transform
 from algora.common.requests import (
-    __get_request, __put_request, __post_request, __delete_request,
+    __get_request,
+    __put_request,
+    __post_request,
+    __delete_request,
 )
 
 
