@@ -4,15 +4,21 @@ Permission API requests.
 from typing import Dict, Any, List
 
 from algora.api.service.permission.__util import (
-    _get_permission_request_info, _delete_permission_request_info, _update_permission_request_info,
-    _create_permission_request_info, _get_permissions_by_resource_id_request_info,
-    _get_permission_by_resource_id_request_info
+    _get_permission_request_info,
+    _delete_permission_request_info,
+    _update_permission_request_info,
+    _create_permission_request_info,
+    _get_permissions_by_resource_id_request_info,
+    _get_permission_by_resource_id_request_info,
 )
 from algora.api.service.permission.model import PermissionRequest
 from algora.common.decorators.data import async_data_request
 from algora.common.function import no_transform
 from algora.common.requests import (
-    __async_get_request, __async_delete_request, __async_post_request, __async_put_request
+    __async_get_request,
+    __async_delete_request,
+    __async_post_request,
+    __async_put_request,
 )
 
 
@@ -47,7 +53,9 @@ async def async_get_permission_by_resource_id(resource_id: str) -> Dict[str, Any
 
 
 @async_data_request(transformers=[no_transform])
-async def async_get_permissions_by_resource_id(resource_id: str) -> List[Dict[str, Any]]:
+async def async_get_permissions_by_resource_id(
+    resource_id: str,
+) -> List[Dict[str, Any]]:
     """
     Asynchronously get all permissions by resource ID.
 
@@ -77,7 +85,9 @@ async def async_create_permission(request: PermissionRequest) -> Dict[str, Any]:
 
 
 @async_data_request(transformers=[no_transform])
-async def async_update_permission(id: str, request: PermissionRequest) -> Dict[str, Any]:
+async def async_update_permission(
+    id: str, request: PermissionRequest
+) -> Dict[str, Any]:
     """
     Asynchronously update permission.
 
