@@ -1,15 +1,17 @@
 from typing import Dict, List
 
 
-from algora.api.service.resource.__util import _upload_resource_request_info, _delete_resource_request_info
+from algora.api.service.resource.__util import (
+    _upload_resource_request_info,
+    _delete_resource_request_info,
+)
 from algora.common.decorators import async_data_request
 from algora.common.function import no_transform
 from algora.common.requests import __async_put_request, __async_delete_request
 
 
 @async_data_request(
-    transformers=[no_transform],
-    processor=lambda response: response.status_code
+    transformers=[no_transform], processor=lambda response: response.status_code
 )
 async def async_upload_resources(path: str, file_locations: List[str]) -> None:
     """
@@ -23,7 +25,7 @@ async def async_upload_resources(path: str, file_locations: List[str]) -> None:
         Dict[str, Any]: Project package response
     """
     # aiofiles doesnt work atm so we are using the blocking open
-    files = [open(location, 'rb') for location in file_locations]
+    files = [open(location, "rb") for location in file_locations]
     request_info = _upload_resource_request_info(path, files)
     response = await __async_put_request(**request_info)
     [file.close() for file in files]
@@ -31,8 +33,7 @@ async def async_upload_resources(path: str, file_locations: List[str]) -> None:
 
 
 @async_data_request(
-    transformers=[no_transform],
-    processor=lambda response: response.status_code
+    transformers=[no_transform], processor=lambda response: response.status_code
 )
 async def async_delete_resource(path: str) -> None:
     """
