@@ -27,7 +27,7 @@ class Base(ABC, BaseModel):
         json_encoders = {
             date: date_to_timestamp,
             datetime: datetime_to_timestamp,
-            tzinfo: str
+            tzinfo: str,
         }
 
     @classmethod
@@ -57,7 +57,7 @@ class Base(ABC, BaseModel):
             bytes: Base-64 encoded data class as bytes
         """
         json_str = json.dumps(self.json(exclude=exclude), sort_keys=True)
-        bytes_rep = bytes(json_str, 'utf-8')
+        bytes_rep = bytes(json_str, "utf-8")
         return base64.b64encode(bytes_rep)
 
     def __hash__(self):
@@ -68,11 +68,7 @@ class Base(ABC, BaseModel):
         """
         return hash((type(self),) + tuple(self.__dict__.items()))
 
-    def copy(
-            self,
-            ignored_fields: List[str] = None,
-            **kwargs
-    ) -> 'Base':
+    def copy(self, ignored_fields: List[str] = None, **kwargs) -> "Base":
         """
         Create a copy of the object
 
@@ -92,4 +88,3 @@ class Base(ABC, BaseModel):
         obj_dict = deep_update(obj_dict, updated_fields)
         [_.unset(obj_dict, field) for field in ignored_fields]
         return cls(**obj_dict)
-
